@@ -13,13 +13,7 @@ use warnings;
 use DateTime;
 use Scalar::Util qw(blessed);
 
-use Moo;
-
-extends 'DBIx::Class::Core';
-
-with('Interchange6::Schema::Role::Errors');
-
-use namespace::clean;
+use base 'DBIx::Class::Core';
 
 __PACKAGE__->load_components(qw(InflateColumn::DateTime TimeStamp));
 
@@ -95,12 +89,11 @@ B<NOTE:> avoid using other methods from L<DBIx::Class::Relationship::Base> since
 
 =head2 zone
 
-For example for storing the UPS/USPS zone code or perhaps a simple name for the zone.
+For example for storing the UPS/USPS zone code or a simple name for the zone.
 
   data_type: 'varchar'
-  default_value: (empty string)
-  is_nullable: 1
-  size: 255
+  is_nullable: 0
+  size: 512
 
 =head2 created
 
@@ -126,12 +119,7 @@ __PACKAGE__->add_columns(
         sequence          => "zones_id_seq"
     },
     "zone",
-    {
-        data_type     => "varchar",
-        default_value => "",
-        is_nullable   => 1,
-        size          => 255
-    },
+    { data_type => "varchar", is_nullable => 0, size  => 512 },
     "created",
     { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
     "last_modified",
@@ -191,7 +179,7 @@ Accessor to related country results ordered by name.
 =cut
 
 __PACKAGE__->many_to_many( "countries", "zone_countries", "country",
-    { order_by => 'Country.name' } );
+    { order_by => 'country.name' } );
 
 =head2 zone_states
 
@@ -215,7 +203,7 @@ Accessor to related state results ordered by name.
 =cut
 
 __PACKAGE__->many_to_many( "states", "zone_states", "state",
-    { order_by => 'State.name' } );
+    { order_by => 'state.name' } );
 
 
 =head2 shipment_destinations
@@ -245,37 +233,113 @@ __PACKAGE__->many_to_many("shipment_methods",
 
 =head2 new
 
-Should not be called directly. Used to set default values for certain rows.
+Overloaded method. We allow a form of multi-create here so you can do something like:
+
+    $schema->resultset('Zone')->create({
+        zone      => 'some states of the USA',
+        countries => [ 'US' ],
+        states    => [ 'CA', 'PA' ],
+    });
+
+If there is only a single country or state the value can be a scalar instead of a hashref.
 
 =cut
 
 sub new {
     my ( $class, $attrs ) = @_;
 
-    $attrs->{zone} = '' unless defined $attrs->{zone};
+    my ( $countries, $states, $new );
 
-    my $new = $class->next::method($attrs);
+    if ( $attrs->{countries} ) {
+        if ( ref($attrs->{countries}) eq 'ARRAY' ) {
+            push @$countries, @{$attrs->{countries}};
+        }
+        else {
+            push @$countries, $attrs->{countries};
+        }
+        delete $attrs->{countries};
+
+        if ( $attrs->{states} ) {
+            if ( ref($attrs->{states}) eq 'ARRAY' ) {
+                push @$states, @{$attrs->{states}};
+            }
+            else {
+                push @$states, $attrs->{states};
+            }
+            delete $attrs->{states};
+        }
+    }
+    elsif ( $attrs->{states} ) {
+        die "Cannot create Zone with states but without countries";
+    }
+
+    $new = $class->next::method($attrs);
+    $new->add_countries($countries) if $countries;
+    $new->add_states($states) if $states;
 
     return $new;
 }
 
 =head2 add_countries
 
-Argument is either a L<Interchange6::Schema::Result::Country> object or an arrayref of the same.
+Argument is one of:
 
-Throws an exception on failure.
+=over 4
+
+=item an L<Interchange6::Schema::Result::Country> object
+
+=item a country ISO code
+
+=item an arrayref of the above (can include a mixture of both)
+
+=back
+
+Returns the zone object on success.
 
 =cut
 
+# add/remove_countries can be passed all sorts of junk but we need Country obj
+
+sub _get_country_obj {
+
+    my ( $self, $country ) = @_;
+
+    if ( !defined $country ) {
+        $self->throw_exception("Country must be defined");
+    }
+    elsif ( blessed($country) ){
+
+        my $class = ref($country);
+
+        $self->throw_exception("Country cannot be a $class")
+            unless $country->isa('Interchange6::Schema::Result::Country');
+
+    }
+    elsif ( $country =~ m/^[a-z]{2}$/i ) {
+
+        my $result = $self->result_source->schema->resultset("Country")
+            ->find( { country_iso_code => uc($country) } );
+
+        $self->throw_exception("No country found for code: $country")
+            unless defined $result;
+
+        $country = $result;
+    }
+    else {
+        $self->throw_exception("Bad country: $country");
+    }
+
+    return $country;
+}
+
 sub add_countries {
     my ( $self, $arg ) = ( shift, shift );
 
     my $schema = $self->result_source->schema;
 
-    $self->clear_errors;
-
     if ( $self->state_count > 0 ) {
-        $self->add_error("Cannot add countries to zone containing states");
+        $self->throw_exception(
+            "Cannot add countries to zone containing states");
     }
     elsif ( ref($arg) ne "ARRAY" ) {
 
@@ -287,44 +351,20 @@ sub add_countries {
 
     my $guard = $schema->txn_scope_guard;
 
-    unless ( $self->has_error ) {
+    foreach my $country (@$arg) {
 
-        # don't try to add countries if we already have errors
+        $country = $self->_get_country_obj( $country );
 
-        foreach my $country (@$arg) {
-
-            unless ( blessed($country)
-                && $country->isa('Interchange6::Schema::Result::Country') )
-            {
-
-                $self->add_error(
-                    "Country must be an Interchange6::Schema::Result::Country");
-                next;
-            }
-
-            if ( $self->has_country($country) ) {
-                $self->add_error(
-                    "Zone already includes country: " . $country->name );
-                next;
-            }
-
-            # be paranoid just in case of unexpected failure
-            eval { $self->add_to_countries($country); };
-            # uncoverable branch true
-            if ($@) {
-                # we really should not arrive here
-                # uncoverable statement
-                $self->add_error($@);
-            }
+        if ( $self->has_country($country) ) {
+            $self->throw_exception(
+                "Zone already includes country: " . $country->name );
         }
+
+        $self->add_to_countries($country);
     }
 
-    if ( $self->has_error ) {
-        $schema->throw_exception( $self->errors_string );
-    }
-    else {
-        $guard->commit;
-    }
+    $guard->commit;
+
     return $self;
 }
 
@@ -344,7 +384,7 @@ sub has_country {
         if ( $country->isa('Interchange6::Schema::Result::Country') ) {
 
             $rset = $self->countries->search(
-                { "Country.country_iso_code" => $country->country_iso_code, } );
+                { "country.country_iso_code" => $country->country_iso_code, } );
             return 1 if $rset->count == 1;
 
         }
@@ -359,7 +399,7 @@ sub has_country {
         if ( $country =~ /^[a-z]{2}$/i ) {
 
             $rset = $self->countries->search(
-                { "Country.country_iso_code" => uc($country) } );
+                { "country.country_iso_code" => uc($country) } );
 
             return 1 if $rset->count == 1;
         }
@@ -367,7 +407,7 @@ sub has_country {
 
             # finally try country name
 
-            $rset = $self->countries->search( { "Country.name" => $country } );
+            $rset = $self->countries->search( { "country.name" => $country } );
 
             return 1 if $rset->count == 1;
         }
@@ -401,11 +441,9 @@ sub remove_countries {
 
     my $schema = $self->result_source->schema;
 
-    $self->clear_errors;
-
     if ( $self->state_count > 0 ) {
 
-        $self->add_error("States must be removed before countries");
+        $self->throw_exception("States must be removed before countries");
 
     }
     elsif ( ref($arg) ne "ARRAY" ) {
@@ -418,66 +456,106 @@ sub remove_countries {
 
     my $guard = $schema->txn_scope_guard;
 
-    unless ( $self->has_error ) {
+    foreach my $country (@$arg) {
 
-        # don't try to remove countries if we already have errors
+        $country = $self->_get_country_obj( $country );
 
-        foreach my $country (@$arg) {
-
-            unless ( blessed($country)
-                && $country->isa('Interchange6::Schema::Result::Country') )
-            {
-
-                $self->add_error(
-                    "Country must be an Interchange6::Schema::Result::Country"
-                );
-                next;
-            }
-
-            unless ( $self->has_country($country) ) {
-                $self->add_error(
-                    "Country does not exist in zone: " . $country->name );
-                next;
-            }
-
-            # be paranoid just in case of unexpected failure
-            eval { $self->remove_from_countries($country); };
-            # uncoverable branch true
-            if ($@) {
-                # we really should not arrive here
-                # uncoverable statement
-                $self->add_error($@);
-            }
+        unless ( $self->has_country($country) ) {
+            $self->throw_exception(
+                "Country does not exist in zone: " . $country->name );
         }
+
+        $self->remove_from_countries($country);
     }
 
-    if ( $self->has_error ) {
-        $schema->throw_exception( $self->errors_string );
-    }
-    else {
-        $guard->commit;
-    }
+    $guard->commit;
+
     return $self;
 }
 
 =head2 add_states
 
-Argument is either a L<Interchange6::Schema::Result::State> object or an arrayref of the same.
+Argument is one of:
 
-Throws an exception on failure.
+=over 4
+
+=item an L<Interchange6::Schema::Result::State> object
+
+=item a state ISO code
+
+=item an arrayref of the above (can include a mixture of both)
+
+=back
+
+Returns the zone object on success.
 
 =cut
 
+# add/remove_states can be passed all sorts of junk but we need State obj
+
+sub _get_state_obj {
+
+    my ( $self, $state ) = @_;
+
+    if ( !defined $state ) {
+        $self->throw_exception("State must be defined");
+    }
+    elsif ( blessed($state) ){
+
+        my $class = ref($state);
+
+        $self->throw_exception("State cannot be a $class")
+            unless $state->isa('Interchange6::Schema::Result::State');
+
+    }
+    elsif ( $state =~ m/^[a-z]{2}$/i ) {
+
+        if ( $self->country_count == 1 ) {
+
+            my $country = $self->countries->first;
+
+            my $result = $self->result_source->schema->resultset("State")->find(
+                {
+                    country_iso_code => $country->country_iso_code,
+                    state_iso_code   => uc($state)
+                }
+            );
+
+            $self->throw_exception("No state found for code: $state")
+                unless defined $result;
+
+            $state = $result;
+
+        }
+        elsif ( $self->country_count == 0 ) {
+
+            $self->throw_exception(
+                "Cannot resolve state_iso_code for zone with no country"
+            );
+        }
+        else {
+
+            $self->throw_exception(
+                "Cannot resolve state_iso_code for zone with > 1 country"
+            );
+        }
+    }
+    else {
+        $self->throw_exception("Bad state: $state");
+    }
+
+    return $state;
+}
+
 sub add_states {
     my ( $self, $arg ) = ( shift, shift );
 
     my $schema = $self->result_source->schema;
 
-    $self->clear_errors;
-
     if ( $self->country_count > 1 ) {
 
-        $self->add_error("Cannot add state to zone with multiple countries");
+        $self->throw_exception(
+            "Cannot add state to zone with multiple countries");
     }
     elsif ( ref($arg) ne "ARRAY" ) {
 
@@ -489,79 +567,47 @@ sub add_states {
 
     my $guard = $schema->txn_scope_guard;
 
-    unless ( $self->has_error ) {
+    foreach my $state (@$arg) {
 
-        # don't try to add states if we already have errors
+        $state = $self->_get_state_obj( $state );
 
-        foreach my $state (@$arg) {
+        if ( $self->country_count == 0 ) {
 
-            unless ( blessed($state)
-                && $state->isa('Interchange6::Schema::Result::State') )
+            # add the country first
+
+            $self->add_countries( $state->country );
+        }
+        else {
+
+            # make sure state is in the existing country
+
+            my $country =
+              $self->countries->search( {}, { rows => 1 } )->single;
+
+            unless ( $country->country_iso_code eq
+                $state->country->country_iso_code )
             {
-
-                $self->add_error(
-                    "State must be an Interchange6::Schema::Result::State");
+                $self->throw_exception( "State "
+                      . $state->name
+                      . " is not in country "
+                      . $country->name );
                 next;
             }
-
-            if ( $self->country_count == 0 ) {
-
-                # add the country first
-
-                # be paranoid just in case of unexpected failure
-                eval { $self->add_countries( $state->country ) };
-                # uncoverable branch true
-                if ($@) {
-                    # we really should not arrive here
-                    # uncoverable statement
-                    $self->add_error($@);
-                    # uncoverable statement
-                    next;
-                }
-            }
-            else {
-
-                # make sure state is in the existing country
-
-                my $country =
-                  $self->countries->search( {}, { rows => 1 } )->single;
-
-                unless ( $country->country_iso_code eq
-                    $state->country->country_iso_code )
-                {
-                    $self->add_error( "State "
-                          . $state->name
-                          . " is not in country "
-                          . $country->name );
-                    next;
-                }
-            }
-
-            if ( $self->has_state($state) ) {
-                $self->add_error(
-                    "Zone already includes state: " . $state->name );
-                next;
-            }
-
-            # try to add the state
-
-            # be paranoid just in case of unexpected failure
-            eval { $self->add_to_states($state); };
-            # uncoverable branch true
-            if ($@) {
-                # we really should not arrive here
-                # uncoverable statement
-                $self->add_error($@);
-            }
         }
+
+        if ( $self->has_state($state) ) {
+            $self->throw_exception(
+                "Zone already includes state: " . $state->name );
+            next;
+        }
+
+        # try to add the state
+
+        $self->add_to_states($state);
     }
 
-    if ( $self->has_error ) {
-        $schema->throw_exception( $self->errors_string );
-    }
-    else {
-        $guard->commit;
-    }
+    $guard->commit;
+
     return $self;
 }
 
@@ -582,8 +628,8 @@ sub has_state {
 
             $rset = $self->states->search(
                 {
-                    "State.country_iso_code" => $state->country_iso_code,
-                    "State.state_iso_code"   => $state->state_iso_code
+                    "state.country_iso_code" => $state->country_iso_code,
+                    "state.state_iso_code"   => $state->state_iso_code
                 }
             );
             return 1 if $rset->count == 1;
@@ -642,8 +688,6 @@ sub remove_states {
 
     my $schema = $self->result_source->schema;
 
-    $self->clear_errors;
-
     if ( ref($arg) ne "ARRAY" ) {
 
         # we need an arrayref
@@ -656,31 +700,13 @@ sub remove_states {
 
     foreach my $state (@$arg) {
 
-        unless ( blessed($state)
-            && $state->isa('Interchange6::Schema::Result::State') )
-        {
+        $state = $self->_get_state_obj( $state );
 
-            $self->add_error(
-                "State must be an Interchange6::Schema::Result::State");
-            next;
-        }
-
-        # be paranoid just in case of unexpected failure
-        eval { $self->remove_from_states($state); };
-        # uncoverable branch true
-        if ($@) {
-            # we really should not arrive here
-            # uncoverable statement
-            $self->add_error($@);
-        }
+        $self->remove_from_states($state);
     }
 
-    if ( $self->has_error ) {
-        $schema->throw_exception( $self->errors_string );
-    }
-    else {
-        $guard->commit;
-    }
+    $guard->commit;
+
     return $self;
 }
 
