@@ -1,9 +1,10 @@
 package Test::Shipment;
 
-use Test::Exception;
+use Test::Most;
 use Test::Roo::Role;
 
 use DateTime;
+use Number::Format qw(format_number);
 
 test 'shipment tests' => sub {
 
@@ -13,7 +14,7 @@ test 'shipment tests' => sub {
 
     my ( $rset, %countries, %states, %zones, $data, $result );
 
-    my $schema = $self->ic6s_schema;
+    my $schema = $self->schema;
 
     # grab a few things from fixtures
 
@@ -29,50 +30,75 @@ test 'shipment tests' => sub {
       $self->addresses->search( { users_id => $user->id, type => 'shipping' } )
       ->first;
 
+    # populate ShipmentCarriers
+
     my %carrier;
 
-    lives_ok(
-        sub {
-            $carrier{UPS} = $self->shipment_carriers->search( { name => 'UPS' },
-                { rows => 1 } )->single;
+    $carrier{UPS} = $schema->resultset("ShipmentCarrier")->create(
+        {
+            name           => 'UPS',
+            account_number => '1Z99999',
         },
-        "grab carrier UPS"
     );
-    cmp_ok( $carrier{UPS}->account_number,
-        'eq', '1U99999', "check account number" );
+
+    #populate shipment methods
+    $schema->resultset("ShipmentMethod")->populate(
+        [
+            {
+                shipment_carriers_id => $carrier{UPS}->id,
+                name                 => '1DM',
+                title                => 'Next Day Air Early AM',
+                max_weight           => '150',
+            },
+            {
+                shipment_carriers_id => $carrier{UPS}->id,
+                name                 => 'GNDRES',
+                title                => 'Ground Residential',
+                max_weight           => '150',
+            },
+        ]
+    );
+
+    ok( $carrier{UPS}->id eq '1', "Testing ShipmentCarrier record creation." )
+      || diag "UPS ShipmentCarrier id: " . $carrier{UPS}->id;
+
+    my $shipment_method = $schema->resultset("ShipmentMethod")
+      ->find( { title => 'Ground Residential' } );
+
+    ok(
+        $shipment_method->name eq 'GNDRES',
+        "Testing ShipmentMethod record creation."
+    ) || diag "UPS Ground Residential name: " . $shipment_method->name;
+
+    my $lower48 = $self->zones->find( { zone => 'US lower 48' } );
 
     lives_ok(
         sub {
-            $carrier{KISS} =
-              $self->shipment_carriers->search( { name => 'KISS' },
-                { rows => 1 } )->single;
+            $schema->resultset("ShipmentRate")->create(
+                {
+                    zones_id            => $lower48->id,
+                    shipment_methods_id => $shipment_method->id,
+                    min_weight          => '0',
+                    max_weight          => '0',
+                    price               => '9.95',
+                }
+            );
         },
-        "grab carrier KISS"
-    );
-    cmp_ok( $carrier{KISS}->account_number,
-        'eq', '1K99999', "check account number" );
-
-    my $shipment_method;
-    lives_ok(
-        sub {
-            $shipment_method = $schema->resultset("ShipmentMethod")
-              ->find( { title => 'Ground Residential' } );
-        },
-        "find Ground Residential"
+        "create ShipmentRate"
     );
 
-    cmp_ok( $shipment_method->name, 'eq', 'GNDRES', "check name" );
+    my $shipment_rate = $schema->resultset("ShipmentRate")
+      ->find( { shipment_methods_id => $shipment_method->id } );
 
-    my $shipment_rate = $self->shipment_rates->find(
-        { shipment_methods_id => $shipment_method->id } );
+    my $price = format_number( $shipment_rate->price, 2, 1 );
 
-    # ugly use of sprintf as SQLite uses float for numeric which can break test
-    cmp_ok( sprintf("%.02f", $shipment_rate->price), '==', 9.95,
-        "Testing flat rate shipping price for UPS Ground lower 48 states." );
+    ok( $price eq '9.95',
+        "Testing flat rate shipping price for UPS Ground lower 48 states." )
+      || diag "Flat rate shipping price. " . $price;
 
     my ( $product, $order );
 
-    lives_ok( sub { $product = $self->products->first }, "grab a product" );
+    lives_ok( sub { $product = $self->products->first } );
 
     my $shipping_address_id = $shipping_address->id;
     my $billing_address_id  = $billing_address->id;
@@ -108,7 +134,7 @@ test 'shipment tests' => sub {
         "Create order IC60001"
     );
 
-    my $orderline = $order->orderlines->first;
+    my $orderline = $order->find_related( 'orderlines', '1' );
 
     cmp_ok( $orderline->sku, 'eq', $product->sku,
         "Testing Orderline record creation." );
@@ -150,7 +176,7 @@ test 'shipment tests' => sub {
         'eq', '1Z99283WNMS984920498320', "Testing tracking number." );
 
     # cleanup
-    $self->clear_orders;
+    $schema->resultset('Order')->delete_all;
 
 };
 
